@@ -19,3 +19,11 @@ class IRepository:
     @abstractmethod
     def retrieve(self, *args, **kwargs) -> Result:
         return NotImplementedMethodError
+
+    @abstractmethod
+    def retrieve_all(self, *args, **kwargs) -> Result:
+        return NotImplementedMethodError
+
+    @abstractmethod
+    def remove(self, *args, **kwargs) -> Result:
+        return NotImplementedMethodError
