@@ -10,16 +10,16 @@ from petisco.notifier.domain.notifier_message import NotifierMessage
 class NotifierExceptionMessage(NotifierMessage):
     def __init__(
         self,
-        function: str,
+        executor: str,
         exception: Exception,
         traceback: str,
         info_id: InfoId = None,
         info_petisco: Dict = None,
     ):
         super().__init__(info_id=info_id, info_petisco=info_petisco)
-        self.function = function
+        self.executor = executor
         self.exception = exception
         self.traceback = traceback
 
     def __str__(self) -> str:
-        return f"Error {self.function}: {repr(self.exception.__class__)} {self.exception} | {self.traceback}"
+        return f"Error {self.executor}: {repr(self.exception.__class__)} {self.exception} | {self.traceback}"
